@@ -5,7 +5,7 @@
  *                                                                      *
  * This program is free software; you can redistribute it and/or modify *
  * it under the terms of the GNU General Public License as published by *
- * the Free Software Foundation; either version 3 of the License, or    *
+ * the Free Software Foundation; either version 2 or version 3 of the License, or    *
  * (at your option) any later version.                                  *
  *                                                                      *
  * This program is distributed in the hope that it will be useful, but  *
@@ -58,7 +58,7 @@ CustomBuildSystem::CustomBuildSystem( QObject *parent, const QVariantList & )
     KDEV_USE_EXTENSION_INTERFACE( KDevelop::IProjectBuilder )
     KDEV_USE_EXTENSION_INTERFACE( KDevelop::IProjectFileManager )
     KDEV_USE_EXTENSION_INTERFACE( KDevelop::IBuildSystemManager )
-
+    setImportFileNameFilter( QStringList() << ".git" << "CVS" << ".svn" << "_svn" << ".kdev4" << "SCCS" << "_darcs" << ".hg" << ".bzr" );
 }
 
 CustomBuildSystem::~CustomBuildSystem()
@@ -104,7 +104,7 @@ KUrl CustomBuildSystem::buildDirectory( ProjectBaseItem*  item ) const
     return builddir;
 }
 
-IProjectBuilder* CustomBuildSystem::builder( ProjectFolderItem*  ) const
+IProjectBuilder* CustomBuildSystem::builder() const
 {
     return const_cast<IProjectBuilder*>(dynamic_cast<const IProjectBuilder*>(this));
 }
